@@ -1,4 +1,4 @@
 from .attributes_logistic import AttributesLogistic
 from .attributes_linear import AttributesLinear
 from .attributes_logistic_parallel import AttributesLogisticParallel
-from .attributes_univariate import AttributesUnivariate
+from .attributes_factory import AttributesFactory
\ No newline at end of file
